as_prediction_clust: Convert to a Cluster Prediction

View source: R/as_prediction_clust.R

as_prediction_clustR Documentation

Convert to a Cluster Prediction

Description

Convert object to a PredictionClust. For a data.frame, the columns row_ids and partition are required. Columns prefixed with prob. are collected into the probability matrix, weights are stored as measure weights, and all remaining columns are stored as extra data in the extra field of the prediction.

Usage

as_prediction_clust(x, ...)

## S3 method for class 'PredictionClust'
as_prediction_clust(x, ...)

## S3 method for class 'data.frame'
as_prediction_clust(x, ...)

Arguments

x

(any)
Object to convert.

...

(any)
Additional arguments.

Value

PredictionClust.

Examples


# create a prediction object
task = tsk("usarrests")
learner = lrn("clust.cmeans", predict_type = "prob")
learner$train(task)
p = learner$predict(task)

# convert to a data.table
tab = as.data.table(p)

# convert back to a Prediction
as_prediction_clust(tab)

# split data.table into a 3 data.tables based on UrbanPop
f = cut(task$data(rows = tab$row_ids)$UrbanPop, 3)
tabs = split(tab, f)

# convert back to list of predictions
preds = lapply(tabs, as_prediction_clust)

# calculate performance in each group
sapply(preds, function(p) p$score(task = task))


mlr3cluster documentation built on Sept. 17, 2026, 5:09 p.m.