Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.MBatchKMeans: Mini Batch K-Means Clustering Learner

Description

A LearnerClust for mini batch k-means clustering implemented in ClusterR::MiniBatchKmeans(). ClusterR::MiniBatchKmeans() doesn't have a default value for the number of clusters. Therefore, the clusters parameter here is set to 2 by default. The predict method uses ClusterR::predict_MBatchKMeans() to compute the cluster memberships for new data. The learner supports both partitional and fuzzy clustering.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.MBatchKMeans")
lrn("clust.MBatchKMeans")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”, “prob”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, ClusterR

Parameters

IdTypeDefaultLevelsRange
clustersinteger2\([1, \infty)\)
batch_sizeinteger10\([1, \infty)\)
num_initinteger1\([1, \infty)\)
max_itersinteger100\([1, \infty)\)
init_fractionnumeric1\([0, 1]\)
initializercharacterkmeans++optimal_init, quantile_init, kmeans++, random-
early_stop_iterinteger10\([1, \infty)\)
verboselogicalFALSETRUE, FALSE-
CENTROIDSuntyped-
tolnumeric1e-04\([0, \infty)\)
tol_optimal_initnumeric0.3\([0, \infty)\)
seedinteger1\((-\infty, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustMiniBatchKMeans

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustMiniBatchKMeans$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustMiniBatchKMeans$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Sculley, David (2010). “Web-scale k-means clustering.” In Proceedings of the 19th international conference on World wide web, 1177--1178.

See Also

Other Learner: mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("ClusterR")) {
  learner = mlr3::lrn("clust.MBatchKMeans")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab