mlr_learners_clust.agnes: Agglomerative Nesting Clustering Learner

mlr_learners_clust.agnesR Documentation

Agglomerative Nesting Clustering Learner

Description

Agglomerative hierarchical clustering. Calls cluster::agnes() from package cluster.

The predict method uses stats::cutree() which cuts the tree resulting from hierarchical clustering into specified number of groups (see parameter k). The default number for k is 2.

Initial parameter values

  • keep.diss:

    • Actual default: n < 100, where n is the number of observations.

    • Adjusted default: FALSE.

    • Reason for change: Avoid storing the dissimilarity matrix in the model to save memory.

  • keep.data:

    • Actual default: TRUE.

    • Adjusted default: FALSE.

    • Reason for change: Avoid storing the training data in the model to save memory.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.agnes")
lrn("clust.agnes")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, cluster

Parameters

Id Type Default Levels Range
metric character euclidean euclidean, manhattan -
stand logical FALSE TRUE, FALSE -
method character average average, single, complete, ward, weighted, flexible, gaverage -
keep.diss logical - TRUE, FALSE -
keep.data logical TRUE TRUE, FALSE -
trace.lev integer 0 [0, \infty)
k integer - [1, \infty)
par.method untyped - -

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustAgnes

Methods

Public methods

Inherited methods

LearnerClustAgnes$new()

Creates a new instance of this R6 class.

Usage
LearnerClustAgnes$new()

LearnerClustAgnes$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustAgnes$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Kaufman, Leonard, Rousseeuw, J P (2009). Finding groups in data: an introduction to cluster analysis. John Wiley & Sons.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.agnes")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.