mlr_learners_clust.ap: Affinity Propagation Clustering Learner

mlr_learners_clust.apR Documentation

Affinity Propagation Clustering Learner

Description

Affinity Propagation clustering. Calls apcluster::apcluster() from package apcluster.

Note that apcluster::apcluster() doesn't have a default for the similarity function. The predict method computes the closest cluster exemplar to find the cluster memberships for new data. The code is taken from StackOverflow answer by the apcluster package maintainer.

Initial parameter values

  • includeSim:

    • Actual default: TRUE.

    • Adjusted default: FALSE.

    • Reason for change: Avoid storing the n x n similarity matrix in the model.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.ap")
lrn("clust.ap")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, apcluster

Parameters

Id Type Default Levels Range
s untyped - -
p untyped NA_real_ -
q numeric NA [0, 1]
maxits integer 1000 [1, \infty)
convits integer 100 [1, \infty)
lam numeric 0.9 [0.5, 1]
includeSim logical TRUE TRUE, FALSE -
details logical FALSE TRUE, FALSE -
nonoise logical FALSE TRUE, FALSE -
seed integer NA (-\infty, \infty)

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustAP

Methods

Public methods

Inherited methods

LearnerClustAP$new()

Creates a new instance of this R6 class.

Usage
LearnerClustAP$new()

LearnerClustAP$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustAP$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Bodenhofer, Ulrich, Kothmeier, Andreas, Hochreiter, Sepp (2011). “APCluster: an R package for affinity propagation clustering.” Bioinformatics, 27(17), 2463–2464.

Frey, J B, Dueck, Delbert (2007). “Clustering by passing messages between data points.” science, 315(5814), 972–976.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.ap")
print(learner)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.