mlr_learners_clust.clara: CLARA Clustering Learner

mlr_learners_clust.claraR Documentation

CLARA Clustering Learner

Description

Clustering Large Applications (CLARA) clustering. Calls cluster::clara() from package cluster.

CLARA extends the PAM algorithm to handle larger datasets by working on sub-datasets of fixed size. The k parameter is set to 2 by default since cluster::clara() doesn't have a default value for the number of clusters. The predict method uses clue::cl_predict() to compute the cluster memberships for new data.

Initial parameter values

  • keep.data:

    • Actual default: TRUE.

    • Adjusted default: FALSE.

    • Reason for change: Avoid storing the training data in the model to save memory.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.clara")
lrn("clust.clara")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, cluster, clue

Parameters

Id Type Default Levels Range
k integer - [1, \infty)
metric character euclidean euclidean, manhattan, jaccard -
stand logical FALSE TRUE, FALSE -
samples integer 5 [1, \infty)
sampsize integer - [1, \infty)
trace integer 0 [0, \infty)
medoids.x logical TRUE TRUE, FALSE -
keep.data logical TRUE TRUE, FALSE -
rngR logical FALSE TRUE, FALSE -
pamLike logical FALSE TRUE, FALSE -
correct.d logical TRUE TRUE, FALSE -

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustCLARA

Methods

Public methods

Inherited methods

LearnerClustCLARA$new()

Creates a new instance of this R6 class.

Usage
LearnerClustCLARA$new()

LearnerClustCLARA$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustCLARA$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Kaufman, Leonard, Rousseeuw, J P (2009). Finding groups in data: an introduction to cluster analysis. John Wiley & Sons.

Schubert, Erich, Rousseeuw, J P (2019). “Faster k-medoids clustering: improving the PAM, CLARA, and CLARANS algorithms.” In Similarity Search and Applications: 12th International Conference, SISAP 2019, Newark, NJ, USA, October 2–4, 2019, Proceedings 12, 171–187. Springer.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.clara")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.