Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.em: Expectation-Maximization Clustering Learner

Description

A LearnerClust for Expectation-Maximization clustering implemented in RWeka::list_Weka_interfaces(). The predict method uses RWeka::predict.Weka_clusterer() to compute the cluster memberships for new data.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.em")
lrn("clust.em")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, RWeka

Parameters

IdTypeDefaultLevelsRange
Iinteger100\([1, \infty)\)
ll_cvnumeric1e-06\([1e-06, \infty)\)
ll_iternumeric1e-06\([1e-06, \infty)\)
Mnumeric1e-06\([1e-06, \infty)\)
maxinteger-1\([-1, \infty)\)
Ninteger-1\([-1, \infty)\)
num_slotsinteger1\([1, \infty)\)
Sinteger100\([0, \infty)\)
Xinteger10\([1, \infty)\)
Kinteger10\([1, \infty)\)
VlogicalFALSETRUE, FALSE-
output_debug_infologicalFALSETRUE, FALSE-

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustEM

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustEM$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustEM$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Witten, H I, Frank, Eibe (2002). “Data mining: practical machine learning tools and techniques with Java implementations.” Acm Sigmod Record, 31(1), 76--77.

Dempster, P A, Laird, M N, Rubin, B D (1977). “Maximum likelihood from incomplete data via the EM algorithm.” Journal of the royal statistical society: series B (methodological), 39(1), 1--22.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("RWeka")) {
  learner = mlr3::lrn("clust.em")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab