Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.featureless: Featureless Clustering Learner

Description

A simple LearnerClust which randomly (but evenly) assigns observations to num_clusters partitions (default: 1 partition).

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.featureless")
lrn("clust.featureless")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”, “prob”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster

Parameters

IdTypeDefaultRange
num_clustersinteger-\([1, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustFeatureless

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustFeatureless$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustFeatureless$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("mlr3")) {
  learner = mlr3::lrn("clust.featureless")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab