| mlr_learners_clust.genie | R Documentation |
Genie hierarchical clustering, a fast and robust outlier-resistant algorithm based on the Gini inequality measure
applied to cluster sizes during the linkage process.
Calls genieclust::gclust() from package genieclust.
There is no predict method for genieclust::gclust(), so the method returns cluster labels for the training data
obtained via stats::cutree() at the requested k.
This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():
mlr_learners$get("clust.genie")
lrn("clust.genie")
Task type: “clust”
Predict Types: “partition”
Feature Types: “logical”, “integer”, “numeric”
Required Packages: mlr3, mlr3cluster, genieclust
| Id | Type | Default | Levels | Range |
| gini_threshold | numeric | 0.3 | [0, 1] |
|
| M | integer | 0 | [0, \infty) |
|
| distance | character | euclidean | euclidean, l2, manhattan, cityblock, l1, cosine | - |
| verbose | logical | FALSE | TRUE, FALSE | - |
| k | integer | - | [1, \infty) |
|
mlr3::Learner -> LearnerClust -> LearnerClustGenie
LearnerClustGenie$new()Creates a new instance of this R6 class.
LearnerClustGenie$new()
LearnerClustGenie$clone()The objects of this class are cloneable with this method.
LearnerClustGenie$clone(deep = FALSE)
deepWhether to make a deep clone.
Gagolewski, Marek, Bartoszuk, Maciej, Cena, Anna (2016). “Genie: A new, fast, and outlier-resistant hierarchical clustering algorithm.” Information Sciences, 363, 8–23. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.ins.2016.05.003")}.
Gagolewski, Marek (2021). “genieclust: Fast and robust hierarchical clustering.” SoftwareX, 15, 100722. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.softx.2021.100722")}.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html#sec-learners
Package mlr3extralearners for more learners.
Dictionary of Learners: mlr3::mlr_learners
as.data.table(mlr_learners) for a table of available Learners in the running session (depending on the loaded packages).
mlr3pipelines to combine learners with pre- and postprocessing steps.
Package mlr3viz for some generic visualizations.
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
mlr3tuning for tuning of hyperparameters, mlr3tuningspaces for established default tuning spaces.
Other Learner:
mlr_learners_clust.MBatchKMeans,
mlr_learners_clust.SimpleKMeans,
mlr_learners_clust.agnes,
mlr_learners_clust.ap,
mlr_learners_clust.bico,
mlr_learners_clust.birch,
mlr_learners_clust.clara,
mlr_learners_clust.cmeans,
mlr_learners_clust.cobweb,
mlr_learners_clust.dbscan,
mlr_learners_clust.dbscan_fpc,
mlr_learners_clust.diana,
mlr_learners_clust.em,
mlr_learners_clust.fanny,
mlr_learners_clust.featureless,
mlr_learners_clust.ff,
mlr_learners_clust.flexmix,
mlr_learners_clust.hclust,
mlr_learners_clust.hdbscan,
mlr_learners_clust.kcca,
mlr_learners_clust.kkmeans,
mlr_learners_clust.kmeans,
mlr_learners_clust.kproto,
mlr_learners_clust.mclust,
mlr_learners_clust.meanshift,
mlr_learners_clust.movMF,
mlr_learners_clust.optics,
mlr_learners_clust.pam,
mlr_learners_clust.protoclust,
mlr_learners_clust.skmeans,
mlr_learners_clust.som,
mlr_learners_clust.specc,
mlr_learners_clust.stdbscan,
mlr_learners_clust.tclust,
mlr_learners_clust.xmeans
# Define the Learner and set parameter values
learner = lrn("clust.genie")
print(learner)
# Define a Task
task = tsk("usarrests")
# Train the learner on the task
learner$train(task)
# Print the model
print(learner$model)
# Make predictions for the task
prediction = learner$predict(task)
# Score the predictions
prediction$score(task = task)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.