mlr_learners_clust.gmeans: G-Means Clustering Learner

mlr_learners_clust.gmeansR Documentation

G-Means Clustering Learner

Description

G-means clustering. Calls gmeans::gmeans() from package gmeans.

G-means extends k-means by automatically determining the number of clusters: starting from k_init centers, each cluster is repeatedly split in two unless an Anderson-Darling test suggests its points already follow a Gaussian distribution, until no more centers are added or k_max is reached. The predict method assigns new observations to the nearest cluster center.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.gmeans")
lrn("clust.gmeans")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, gmeans

Parameters

Id Type Default Levels Range
k_init integer 2 [1, \infty)
k_max integer 10 [1, \infty)
level numeric 0.05 [0, 1]
iter.max integer 10 [1, \infty)
algorithm character Hartigan-Wong Hartigan-Wong, Lloyd, Forgy, MacQueen -
trace logical FALSE TRUE, FALSE -
method character euclidean euclidean, manhattan, minkowski -
p numeric 2 [0, \infty)

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustGMeans

Methods

Public methods

Inherited methods

LearnerClustGMeans$new()

Creates a new instance of this R6 class.

Usage
LearnerClustGMeans$new()

LearnerClustGMeans$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustGMeans$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Hamerly, Greg, Elkan, Charles (2003). “Learning the k in k-means.” In Advances in Neural Information Processing Systems, volume 16.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kmeans_rcpp, mlr_learners_clust.kmodes, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.gmeans")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on Aug. 22, 2026, 1:07 a.m.