Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.kmeans: K-Means Clustering Learner

Description

A LearnerClust for k-means clustering implemented in stats::kmeans(). stats::kmeans() doesn't have a default value for the number of clusters. Therefore, the centers parameter here is set to 2 by default. The predict method uses clue::cl_predict() to compute the cluster memberships for new data.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.kmeans")
lrn("clust.kmeans")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, 'stats', clue

Parameters

IdTypeDefaultLevelsRange
centersuntyped--
iter.maxinteger10\([1, \infty)\)
algorithmcharacterHartigan-WongHartigan-Wong, Lloyd, Forgy, MacQueen-
nstartinteger1\([1, \infty)\)
traceinteger0\([0, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustKMeans

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustKMeans$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustKMeans$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Forgy, W E (1965). “Cluster analysis of multivariate data: efficiency versus interpretability of classifications.” Biometrics, 21, 768--769.

Hartigan, A J, Wong, A M (1979). “Algorithm AS 136: A K-means clustering algorithm.” Journal of the Royal Statistical Society. Series C (Applied Statistics), 28(1), 100--108. tools:::Rd_expr_doi("10.2307/2346830").

Lloyd, P S (1982). “Least squares quantization in PCM.” IEEE Transactions on Information Theory, 28(2), 129--137.

MacQueen, James (1967). “Some methods for classification and analysis of multivariate observations.” In Proceedings of the Fifth Berkeley Symposium on Mathematical Statistics and Probability, volume 1, 281--297.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("stats") && requireNamespace("clue")) {
  learner = mlr3::lrn("clust.kmeans")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab