mlr_learners_clust.mclust: Gaussian Mixture Model Clustering Learner

mlr_learners_clust.mclustR Documentation

Gaussian Mixture Model Clustering Learner

Description

Gaussian mixture model-based clustering. Calls mclust::Mclust() from package mclust.

The predict method uses mclust::predict.Mclust() to compute the cluster memberships for new data.

Initial parameter values

  • verbose:

    • Actual default: interactive().

    • Adjusted default: FALSE.

    • Reason for change: Suppress progress output during training.

  • warn:

    • Actual default: mclust.options("warn"), which is FALSE by default.

    • Adjusted default: FALSE.

    • Reason for change: Suppress warnings during training independently of the mclust global options.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.mclust")
lrn("clust.mclust")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”, “prob”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, mclust

Parameters

Id Type Default Levels
G untyped 1:9
modelNames untyped -
prior untyped -
control untyped -
initialization untyped -
warn logical FALSE TRUE, FALSE
x untyped -
verbose logical FALSE TRUE, FALSE

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustMclust

Methods

Public methods

Inherited methods

LearnerClustMclust$new()

Creates a new instance of this R6 class.

Usage
LearnerClustMclust$new()

LearnerClustMclust$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustMclust$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Scrucca, Luca, Fop, Michael, Murphy, Brendan T, Raftery, E A (2016). “mclust 5: clustering, classification and density estimation using Gaussian finite mixture models.” The R journal, 8(1), 289.

Fraley, Chris, Raftery, E A (2002). “Model-based clustering, discriminant analysis, and density estimation.” Journal of the American statistical Association, 97(458), 611–631.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.mclust")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.