mlr_learners_clust.meanshift: Mean Shift Clustering Learner

mlr_learners_clust.meanshiftR Documentation

Mean Shift Clustering Learner

Description

Mean shift clustering. Calls LPCM::ms() from package LPCM.

There is no predict method for LPCM::ms(), so the method returns cluster labels for the training data.

Initial parameter values

  • plot:

    • Actual default: TRUE.

    • Adjusted default: FALSE.

    • Reason for change: Suppress plotting during training.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.meanshift")
lrn("clust.meanshift")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, LPCM

Parameters

Id Type Default Levels Range
h untyped - -
subset untyped - -
thr numeric 0.01 (-\infty, \infty)
scaled integer 1 [0, \infty)
iter integer 200 [1, \infty)
plot logical TRUE TRUE, FALSE -

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustMeanShift

Methods

Public methods

Inherited methods

LearnerClustMeanShift$new()

Creates a new instance of this R6 class.

Usage
LearnerClustMeanShift$new()

LearnerClustMeanShift$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustMeanShift$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Cheng, Yizong (1995). “Mean shift, mode seeking, and clustering.” IEEE transactions on pattern analysis and machine intelligence, 17(8), 790–799.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.meanshift")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.