mlr_learners_clust.movMF: von Mises-Fisher Mixture Clustering Learner

mlr_learners_clust.movMFR Documentation

von Mises-Fisher Mixture Clustering Learner

Description

Fits a mixture of von Mises-Fisher distributions via EM, the directional-data analogue of a Gaussian mixture for points on the unit hypersphere. Calls movMF::movMF() from package movMF.

The k parameter is set to 2 by default since movMF::movMF() has no default value for the number of mixture components. Rows of x are standardised to unit length internally by movMF::movMF(). Predictions use the predict() method from movMF; prob returns the soft memberships.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.movMF")
lrn("clust.movMF")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”, “prob”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, movMF

Parameters

Id Type Default Levels Range
k integer - [1, \infty)
E character softmax softmax, hardmax, stochmax -
kappa untyped - -
start untyped "p" -
nruns integer 1 [1, \infty)
maxiter integer 100 [1, \infty)
reltol numeric - [0, \infty)
minalpha numeric 0 [0, \infty)
converge logical TRUE TRUE, FALSE -
verbose logical FALSE TRUE, FALSE -

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustMovMF

Methods

Public methods

Inherited methods

LearnerClustMovMF$new()

Creates a new instance of this R6 class.

Usage
LearnerClustMovMF$new()

LearnerClustMovMF$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustMovMF$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Banerjee, Arindam, Dhillon, S I, Ghosh, Joydeep, Sra, Suvrit (2005). “Clustering on the Unit Hypersphere using von Mises-Fisher Distributions.” Journal of Machine Learning Research, 6(46), 1345–1382.

Hornik, Kurt, Grün, Bettina (2014). “movMF: An R Package for Fitting Mixtures of von Mises-Fisher Distributions.” Journal of Statistical Software, 58(10), 1–31. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v058.i10")}.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.movMF")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.