Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.optics: Ordering Points to Identify the Clustering Structure (OPTICS) Clustering Learner

Description

OPTICS (Ordering points to identify the clustering structure) point ordering clustering. Calls dbscan::optics() from dbscan.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.optics")
lrn("clust.optics")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, dbscan

Parameters

IdTypeDefaultLevelsRange
epsnumericNULL\([0, \infty)\)
minPtsinteger5\([0, \infty)\)
searchcharacterkdtreekdtree, linear, dist-
bucketSizeinteger10\([1, \infty)\)
splitRulecharacterSUGGESTSTD, MIDPT, FAIR, SL_MIDPT, SL_FAIR, SUGGEST-
approxnumeric0\((-\infty, \infty)\)
eps_clnumeric-\([0, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustOPTICS

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustOPTICS$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustOPTICS$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Hahsler M, Piekenbrock M, Doran D (2019). “dbscan: Fast Density-Based Clustering with R.” Journal of Statistical Software, 91(1), 1--30. tools:::Rd_expr_doi("10.18637/jss.v091.i01").

Ankerst, Mihael, Breunig, M M, Kriegel, Hans-Peter, Sander, Jörg (1999). “OPTICS: Ordering points to identify the clustering structure.” ACM Sigmod record, 28(2), 49--60.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("dbscan")) {
  learner = mlr3::lrn("clust.optics")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab