mlr_learners_clust.specc: Spectral Clustering Learner

mlr_learners_clust.speccR Documentation

Spectral Clustering Learner

Description

Spectral clustering. Calls kernlab::specc() from package kernlab.

The centers parameter is set to 2 by default since kernlab::specc() doesn't have a default value for the number of clusters. Kernel parameters have to be passed directly and not by using the kpar list in kernlab::specc().

There is no predict method for kernlab::specc(), so the method returns cluster labels for the training data.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.specc")
lrn("clust.specc")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, kernlab

Parameters

Id Type Default Levels Range
centers integer - [1, \infty)
kernel character rbfdot rbfdot, polydot, vanilladot, tanhdot, laplacedot, besseldot, anovadot, splinedot -
sigma numeric - [0, \infty)
degree integer 3 [1, \infty)
scale numeric 1 [0, \infty)
offset numeric 1 (-\infty, \infty)
order integer 1 (-\infty, \infty)
nystrom.red logical FALSE TRUE, FALSE -
nystrom.sample integer - [1, \infty)
iterations integer 200 [1, \infty)
mod.sample numeric 0.75 [0, 1]

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustSpectral

Methods

Public methods

Inherited methods

LearnerClustSpectral$new()

Creates a new instance of this R6 class.

Usage
LearnerClustSpectral$new()

LearnerClustSpectral$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustSpectral$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Karatzoglou, Alexandros, Smola, Alexandros, Hornik, Kurt, Zeileis, Achim (2004). “kernlab-an S4 package for kernel methods in R.” Journal of statistical software, 11, 1–20.

Ng, Y A, Jordan, I M, Weiss, Yair (2001). “On Spectral Clustering: Analysis and an Algorithm.” In Advances in Neural Information Processing Systems, volume 14.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.stdbscan, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.specc")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.