mlr_learners_clust.stdbscan: ST-DBSCAN Clustering Learner

mlr_learners_clust.stdbscanR Documentation

ST-DBSCAN Clustering Learner

Description

ST-DBSCAN (spatio-temporal density-based spatial clustering of applications with noise) clustering. Calls stdbscan::st_dbscan() from package stdbscan.

The task must have exactly 3 features: the first two features (in the task's feature order, which is alphabetical for newly created tasks) are used as the spatial coordinates and the third feature as the temporal coordinate.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.stdbscan")
lrn("clust.stdbscan")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, stdbscan

Parameters

Id Type Default Levels Range
eps_spatial numeric - [0, \infty)
eps_temporal numeric - [0, \infty)
min_pts integer - [1, \infty)
weights untyped - -
borderPoints logical TRUE TRUE, FALSE -
search character kdtree kdtree, linear, dist -
bucketSize integer 10 [1, \infty)
splitRule character SUGGEST STD, MIDPT, FAIR, SL_MIDPT, SL_FAIR, SUGGEST -
approx numeric 0 (-\infty, \infty)

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustSTDBSCAN

Methods

Public methods

Inherited methods

LearnerClustSTDBSCAN$new()

Creates a new instance of this R6 class.

Usage
LearnerClustSTDBSCAN$new()

LearnerClustSTDBSCAN$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustSTDBSCAN$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

Birant, Derya, Kut, Alp (2007). “ST-DBSCAN: An algorithm for clustering spatial-temporal data.” Data & Knowledge Engineering, 60(1), 208–221. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.datak.2006.01.013")}.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.gmeans, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kmeans_rcpp, mlr_learners_clust.kmodes, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.tclust, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.stdbscan")
print(learner)


mlr3cluster documentation built on Aug. 22, 2026, 1:07 a.m.