mlr_learners_clust.tclust: Robust Trimmed Clustering Learner

mlr_learners_clust.tclustR Documentation

Robust Trimmed Clustering Learner

Description

Robust trimmed clustering. Each cluster is modeled by a multivariate Gaussian; the most outlying alpha fraction of observations is trimmed and labeled with cluster 0 in the returned partition. Calls tclust::tclust() from package tclust.

The k parameter is set to 2 by default since tclust::tclust() doesn't have a default value for the number of clusters. There is no predict method for tclust::tclust(), so the method returns cluster labels for the training data.

Initial parameter values

  • store_x:

    • Actual default: TRUE.

    • Adjusted default: FALSE.

    • Reason for change: Avoid storing the training data in the model to save memory.

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.tclust")
lrn("clust.tclust")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, tclust

Parameters

Id Type Default Levels Range
k integer - [1, \infty)
alpha numeric 0.05 [0, 0.5]
nstart integer 500 [1, \infty)
niter1 integer 3 [1, \infty)
niter2 integer 20 [1, \infty)
nkeep integer 5 [1, \infty)
iter.max integer - [1, \infty)
equal.weights logical FALSE TRUE, FALSE -
restr character eigen eigen, deter -
restr.fact numeric 12 [1, \infty)
cshape numeric 1e+10 [1, \infty)
opt character HARD HARD, MIXT -
center logical FALSE TRUE, FALSE -
scale logical FALSE TRUE, FALSE -
store_x logical TRUE TRUE, FALSE -
parallel logical FALSE TRUE, FALSE -
n.cores integer -1 (-\infty, \infty)
zero_tol numeric 1e-16 [0, \infty)
drop.empty.clust logical TRUE TRUE, FALSE -
trace integer 0 [0, \infty)

Super classes

mlr3::Learner -> LearnerClust -> LearnerClustTclust

Methods

Public methods

Inherited methods

LearnerClustTclust$new()

Creates a new instance of this R6 class.

Usage
LearnerClustTclust$new()

LearnerClustTclust$clone()

The objects of this class are cloneable with this method.

Usage
LearnerClustTclust$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

References

García-Escudero, A L, Gordaliza, Alfonso, Matrán, Carlos, Mayo-Iscar, Agustín (2008). “A general trimming approach to robust cluster analysis.” The Annals of Statistics, 36(3), 1324–1345. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/07-AOS515")}.

Fritz, Heinrich, García-Escudero, A L, Mayo-Iscar, Agustín (2012). “tclust: An R package for a trimming approach to cluster analysis.” Journal of Statistical Software, 47(12), 1–26. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v047.i12")}.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.clara, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.flexmix, mlr_learners_clust.genie, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kcca, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.kproto, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.movMF, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.protoclust, mlr_learners_clust.skmeans, mlr_learners_clust.som, mlr_learners_clust.specc, mlr_learners_clust.stdbscan, mlr_learners_clust.xmeans

Examples


# Define the Learner and set parameter values
learner = lrn("clust.tclust")
print(learner)

# Define a Task
task = tsk("usarrests")

# Train the learner on the task
learner$train(task)

# Print the model
print(learner$model)

# Make predictions for the task
prediction = learner$predict(task)

# Score the predictions
prediction$score(task = task)


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.