mlr_measures_clust.davies_bouldin: Davies-Bouldin Index

mlr_measures_clust.davies_bouldinR Documentation

Davies-Bouldin Index

Description

The Davies-Bouldin index measures the average similarity between each cluster and the cluster most similar to it, where similarity is the ratio of within-cluster scatter to between-cluster separation. It is defined as DB = \frac{1}{k} \sum_{i=1}^{k} \max_{j \neq i} \frac{s_i + s_j}{d_{ij}} where s_i is the average distance of observations in cluster i to its centroid and d_{ij} is the Euclidean distance between centroids i and j. Lower values indicate better clustering.

Dictionary

This mlr3::Measure can be instantiated via the dictionary mlr3::mlr_measures or with the associated sugar function mlr3::msr():

mlr_measures$get("clust.davies_bouldin")
msr("clust.davies_bouldin")

Meta Information

  • Task type: “clust”

  • Range: [0, \infty)

  • Minimize: TRUE

  • Average: macro

  • Required Prediction: “partition”

  • Required Packages: mlr3, mlr3cluster

References

Davies, L D, Bouldin, W D (1979). “A cluster separation measure.” IEEE Transactions on Pattern Analysis and Machine Intelligence, PAMI-1(2), 224–227. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1109/TPAMI.1979.4766909")}.

See Also

Dictionary of Measures: mlr3::mlr_measures

as.data.table(mlr_measures) for a complete table of all (also dynamically created) mlr3::Measure implementations.

Other cluster measures: mlr_measures_clust.avg_between, mlr_measures_clust.avg_within, mlr_measures_clust.ch, mlr_measures_clust.dunn, mlr_measures_clust.dunn2, mlr_measures_clust.entropy, mlr_measures_clust.pearsongamma, mlr_measures_clust.silhouette, mlr_measures_clust.wb_ratio, mlr_measures_clust.wss


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.