| mlr_measures_clust.dunn2 | R Documentation |
An alternative formulation of the Dunn index that uses average distances instead of extremes. It is defined as the
ratio of the minimum average between-cluster distance to the maximum average within-cluster distance:
D_2 = \min_{i \neq j} \bar{d}(C_i, C_j) / \max_k \bar{d}(C_k).
This variant is more robust to outliers than the standard Dunn index. Higher values indicate better separation.
If the task contains factor or ordered features, Gower distances (cluster::daisy()) are used instead of
Euclidean distances.
This mlr3::Measure can be instantiated via the dictionary mlr3::mlr_measures or with the
associated sugar function mlr3::msr():
mlr_measures$get("clust.dunn2")
msr("clust.dunn2")
Task type: “clust”
Range: [0, \infty)
Minimize: FALSE
Average: macro
Required Prediction: “partition”
Required Packages: mlr3, mlr3cluster, cluster
Dunn, C J (1974). “Well-separated clusters and optimal fuzzy partitions.” Journal of Cybernetics, 4(1), 95–104. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01969727408546059")}.
Dictionary of Measures: mlr3::mlr_measures
as.data.table(mlr_measures) for a complete table of all (also dynamically created) mlr3::Measure implementations.
Other cluster measures:
mlr_measures_clust.avg_between,
mlr_measures_clust.avg_within,
mlr_measures_clust.ch,
mlr_measures_clust.davies_bouldin,
mlr_measures_clust.dunn,
mlr_measures_clust.entropy,
mlr_measures_clust.pearsongamma,
mlr_measures_clust.silhouette,
mlr_measures_clust.wb_ratio,
mlr_measures_clust.wss
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.