mlr_measures_clust.pearsongamma: Pearson Gamma

mlr_measures_clust.pearsongammaR Documentation

Pearson Gamma

Description

The Pearson correlation between pairwise distances and a binary indicator of whether two observations belong to different clusters. All within-cluster distances are paired with indicator 0, and all between-cluster distances with indicator 1. Values close to 1 indicate that between-cluster distances tend to be larger than within-cluster distances, suggesting well-separated clusters.

Details

If the task contains factor or ordered features, Gower distances (cluster::daisy()) are used instead of Euclidean distances.

Dictionary

This mlr3::Measure can be instantiated via the dictionary mlr3::mlr_measures or with the associated sugar function mlr3::msr():

mlr_measures$get("clust.pearsongamma")
msr("clust.pearsongamma")

Meta Information

  • Task type: “clust”

  • Range: [-1, 1]

  • Minimize: FALSE

  • Average: macro

  • Required Prediction: “partition”

  • Required Packages: mlr3, mlr3cluster, cluster

See Also

Dictionary of Measures: mlr3::mlr_measures

as.data.table(mlr_measures) for a complete table of all (also dynamically created) mlr3::Measure implementations.

Other cluster measures: mlr_measures_clust.avg_between, mlr_measures_clust.avg_within, mlr_measures_clust.ch, mlr_measures_clust.davies_bouldin, mlr_measures_clust.dunn, mlr_measures_clust.dunn2, mlr_measures_clust.entropy, mlr_measures_clust.silhouette, mlr_measures_clust.wb_ratio, mlr_measures_clust.wss


mlr3cluster documentation built on June 11, 2026, 5:06 p.m.