This Learner specializes mlr3::Learner for cluster problems:
task_type is set to "clust".
Creates Predictions of class PredictionClust.
Possible values for predict_types are:
"partition": Integer indicating the cluster membership.
"prob": Probability for belonging to each cluster.
Predefined learners can be found in the mlr3misc::Dictionary mlr3::mlr_learners.
mlr3::Learner -> LearnerClust
new()Creates a new instance of this R6 class.
LearnerClust$new(
id,
param_set = ps(),
predict_types = "partition",
feature_types = character(),
properties = character(),
packages = character(),
label = NA_character_,
man = NA_character_
)id(character(1))
Identifier for the new instance.
param_set(paradox::ParamSet)
Set of hyperparameters.
predict_types(character())
Supported predict types. Must be a subset of mlr_reflections$learner_predict_types.
feature_types(character())
Feature types the learner operates on. Must be a subset of mlr_reflections$task_feature_types.
properties(character())
Set of properties of the Learner.
Must be a subset of mlr_reflections$learner_properties.
The following properties are currently standardized and understood by learners in mlr3:
"missings": The learner can handle missing values in the data.
"weights": The learner supports observation weights.
"importance": The learner supports extraction of importance scores, i.e. comes with an $importance() extractor function (see section on optional extractors in Learner).
"selected_features": The learner supports extraction of the set of selected features, i.e. comes with a $selected_features() extractor function (see section on optional extractors in Learner).
"oob_error": The learner supports extraction of estimated out of bag error, i.e. comes with a oob_error() extractor function (see section on optional extractors in Learner).
packages(character())
Set of required packages.
A warning is signaled by the constructor if at least one of the packages is not installed,
but loaded (not attached) later on-demand via requireNamespace().
label(character(1))
Label for the new instance.
man(character(1))
String in the format [pkg]::[topic] pointing to a manual page for this object.
The referenced help package can be opened via method $help().
reset()Reset assignments field before calling parent's reset().
LearnerClust$reset()
clone()The objects of this class are cloneable with this method.
LearnerClust$clone(deep = FALSE)deepWhether to make a deep clone.
library(mlr3)
library(mlr3cluster)
ids = mlr_learners$keys("^clust")
ids
# get a specific learner from mlr_learners:
learner = lrn("clust.kmeans")
print(learner)
Run the code above in your browser using DataLab