Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.ap: Affinity Propagation Clustering Learner

Description

A LearnerClust for Affinity Propagation clustering implemented in apcluster::apcluster(). apcluster::apcluster() doesn't have set a default for similarity function. The predict method computes the closest cluster exemplar to find the cluster memberships for new data. The code is taken from StackOverflow answer by the apcluster package maintainer.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.ap")
lrn("clust.ap")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, apcluster

Parameters

IdTypeDefaultLevelsRange
suntyped--
puntypedNA-
qnumeric-\([0, 1]\)
maxitsinteger1000\([1, \infty)\)
convitsinteger100\([1, \infty)\)
lamnumeric0.9\([0.5, 1]\)
includeSimlogicalFALSETRUE, FALSE-
detailslogicalFALSETRUE, FALSE-
nonoiselogicalFALSETRUE, FALSE-
seedinteger-\((-\infty, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustAP

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustAP$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustAP$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Bodenhofer, Ulrich, Kothmeier, Andreas, Hochreiter, Sepp (2011). “APCluster: an R package for affinity propagation clustering.” Bioinformatics, 27(17), 2463--2464.

Frey, J B, Dueck, Delbert (2007). “Clustering by passing messages between data points.” science, 315(5814), 972--976.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("apcluster")) {
  learner = mlr3::lrn("clust.ap")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab