| mlr_learners_clust.fanny | R Documentation |
Fuzzy Analysis (FANNY) clustering.
Calls cluster::fanny() from package cluster.
The k parameter is set to 2 by default since cluster::fanny() doesn't have a default value for the number of
clusters. The predict method copies cluster assignments and memberships generated for train data. The predict does
not work for new data.
keep.diss:
Actual default: n < 100, where n is the number of observations.
Adjusted default: FALSE.
Reason for change: Avoid storing the dissimilarity matrix in the model to save memory.
keep.data:
Actual default: TRUE.
Adjusted default: FALSE.
Reason for change: Avoid storing the training data in the model to save memory.
This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():
mlr_learners$get("clust.fanny")
lrn("clust.fanny")
Task type: “clust”
Predict Types: “partition”, “prob”
Feature Types: “logical”, “integer”, “numeric”
Required Packages: mlr3, mlr3cluster, cluster
| Id | Type | Default | Levels | Range |
| k | integer | - | [1, \infty) |
|
| memb.exp | numeric | 2 | [1, \infty) |
|
| metric | character | euclidean | euclidean, manhattan, SqEuclidean | - |
| stand | logical | FALSE | TRUE, FALSE | - |
| iniMem.p | untyped | NULL | - | |
| keep.diss | logical | - | TRUE, FALSE | - |
| keep.data | logical | TRUE | TRUE, FALSE | - |
| maxit | integer | 500 | [0, \infty) |
|
| tol | numeric | 1e-15 | [0, \infty) |
|
| trace.lev | integer | 0 | [0, \infty) |
|
mlr3::Learner -> LearnerClust -> LearnerClustFanny
LearnerClustFanny$new()Creates a new instance of this R6 class.
LearnerClustFanny$new()
LearnerClustFanny$clone()The objects of this class are cloneable with this method.
LearnerClustFanny$clone(deep = FALSE)
deepWhether to make a deep clone.
Kaufman, Leonard, Rousseeuw, J P (2009). Finding groups in data: an introduction to cluster analysis. John Wiley & Sons.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html#sec-learners
Package mlr3extralearners for more learners.
Dictionary of Learners: mlr3::mlr_learners
as.data.table(mlr_learners) for a table of available Learners in the running session (depending on the loaded packages).
mlr3pipelines to combine learners with pre- and postprocessing steps.
Package mlr3viz for some generic visualizations.
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
mlr3tuning for tuning of hyperparameters, mlr3tuningspaces for established default tuning spaces.
Other Learner:
mlr_learners_clust.MBatchKMeans,
mlr_learners_clust.SimpleKMeans,
mlr_learners_clust.agnes,
mlr_learners_clust.ap,
mlr_learners_clust.bico,
mlr_learners_clust.birch,
mlr_learners_clust.clara,
mlr_learners_clust.cmeans,
mlr_learners_clust.cobweb,
mlr_learners_clust.dbscan,
mlr_learners_clust.dbscan_fpc,
mlr_learners_clust.diana,
mlr_learners_clust.em,
mlr_learners_clust.featureless,
mlr_learners_clust.ff,
mlr_learners_clust.flexmix,
mlr_learners_clust.genie,
mlr_learners_clust.hclust,
mlr_learners_clust.hdbscan,
mlr_learners_clust.kcca,
mlr_learners_clust.kkmeans,
mlr_learners_clust.kmeans,
mlr_learners_clust.kproto,
mlr_learners_clust.mclust,
mlr_learners_clust.meanshift,
mlr_learners_clust.movMF,
mlr_learners_clust.optics,
mlr_learners_clust.pam,
mlr_learners_clust.protoclust,
mlr_learners_clust.skmeans,
mlr_learners_clust.som,
mlr_learners_clust.specc,
mlr_learners_clust.stdbscan,
mlr_learners_clust.tclust,
mlr_learners_clust.xmeans
# Define the Learner and set parameter values
learner = lrn("clust.fanny")
print(learner)
# Define a Task
task = tsk("usarrests")
# Train the learner on the task
learner$train(task)
# Print the model
print(learner$model)
# Make predictions for the task
prediction = learner$predict(task)
# Score the predictions
prediction$score(task = task)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.