Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.fanny: Fuzzy Analysis Clustering Learner

Description

A LearnerClust for fuzzy clustering implemented in cluster::fanny(). cluster::fanny() doesn't have a default value for the number of clusters. Therefore, the k parameter which corresponds to the number of clusters here is set to 2 by default. The predict method copies cluster assignments and memberships generated for train data. The predict does not work for new data.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.fanny")
lrn("clust.fanny")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”, “prob”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, cluster

Parameters

IdTypeDefaultLevelsRange
kinteger-\([1, \infty)\)
memb.expnumeric2\([1, \infty)\)
metriccharactereuclideaneuclidean, manhattan, SqEuclidean-
standlogicalFALSETRUE, FALSE-
maxitinteger500\([0, \infty)\)
tolnumeric1e-15\([0, \infty)\)
trace.levinteger0\([0, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustFanny

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustFanny$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustFanny$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Kaufman, Leonard, Rousseeuw, J P (2009). Finding groups in data: an introduction to cluster analysis. John Wiley & Sons.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("cluster")) {
  learner = mlr3::lrn("clust.fanny")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab