| mlr_learners_clust.kcca | R Documentation |
K-Centroids Cluster Analysis - a unified framework for partitional clustering with selectable distance / centroid
families: standard k-means, k-medians, spherical k-means ("angle"), Jaccard, and extended Jaccard.
Calls flexclust::kcca() from package flexclust.
The k parameter is set to 2 by default since flexclust::kcca() has no default value for the number of clusters.
Predictions dispatch to flexclust's S4 predict method via methods::getMethod("predict", "kccasimple")
rather than calling predict() directly, since both flexclust and kernlab define an S4 class
named "kcca" and the resulting class-cache collision can break S4 dispatch when both packages are loaded.
This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():
mlr_learners$get("clust.kcca")
lrn("clust.kcca")
Task type: “clust”
Predict Types: “partition”
Feature Types: “logical”, “integer”, “numeric”
Required Packages: mlr3, mlr3cluster, flexclust
| Id | Type | Default | Levels | Range |
| k | integer | - | [1, \infty) |
|
| family | character | kmeans | kmeans, kmedians, angle, jaccard, ejaccard | - |
| weights | untyped | - | - | |
| group | untyped | - | - | |
| simple | logical | FALSE | TRUE, FALSE | - |
| save.data | logical | FALSE | TRUE, FALSE | - |
| iter.max | integer | 200 | [1, \infty) |
|
| tolerance | numeric | 1e-06 | [0, \infty) |
|
| verbose | integer | 0 | [0, \infty) |
|
| classify | character | auto | auto, weighted, hard | - |
| initcent | untyped | - | - | |
| gamma | numeric | 1 | [0, \infty) |
|
| ntry | integer | 5 | [1, \infty) |
|
| min.size | integer | 2 | [1, \infty) |
|
mlr3::Learner -> LearnerClust -> LearnerClustKCCA
LearnerClustKCCA$new()Creates a new instance of this R6 class.
LearnerClustKCCA$new()
LearnerClustKCCA$clone()The objects of this class are cloneable with this method.
LearnerClustKCCA$clone(deep = FALSE)
deepWhether to make a deep clone.
Leisch, Friedrich (2006). “A Toolbox for K-Centroids Cluster Analysis.” Computational Statistics & Data Analysis, 51(2), 526–544. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.csda.2005.10.006")}.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html#sec-learners
Package mlr3extralearners for more learners.
Dictionary of Learners: mlr3::mlr_learners
as.data.table(mlr_learners) for a table of available Learners in the running session (depending on the loaded packages).
mlr3pipelines to combine learners with pre- and postprocessing steps.
Package mlr3viz for some generic visualizations.
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
mlr3tuning for tuning of hyperparameters, mlr3tuningspaces for established default tuning spaces.
Other Learner:
mlr_learners_clust.MBatchKMeans,
mlr_learners_clust.SimpleKMeans,
mlr_learners_clust.agnes,
mlr_learners_clust.ap,
mlr_learners_clust.bico,
mlr_learners_clust.birch,
mlr_learners_clust.clara,
mlr_learners_clust.cmeans,
mlr_learners_clust.cobweb,
mlr_learners_clust.dbscan,
mlr_learners_clust.dbscan_fpc,
mlr_learners_clust.diana,
mlr_learners_clust.em,
mlr_learners_clust.fanny,
mlr_learners_clust.featureless,
mlr_learners_clust.ff,
mlr_learners_clust.flexmix,
mlr_learners_clust.genie,
mlr_learners_clust.hclust,
mlr_learners_clust.hdbscan,
mlr_learners_clust.kkmeans,
mlr_learners_clust.kmeans,
mlr_learners_clust.kproto,
mlr_learners_clust.mclust,
mlr_learners_clust.meanshift,
mlr_learners_clust.movMF,
mlr_learners_clust.optics,
mlr_learners_clust.pam,
mlr_learners_clust.protoclust,
mlr_learners_clust.skmeans,
mlr_learners_clust.som,
mlr_learners_clust.specc,
mlr_learners_clust.stdbscan,
mlr_learners_clust.tclust,
mlr_learners_clust.xmeans
# Define the Learner and set parameter values
learner = lrn("clust.kcca")
print(learner)
# Define a Task
task = tsk("usarrests")
# Train the learner on the task
learner$train(task)
# Print the model
print(learner$model)
# Make predictions for the task
prediction = learner$predict(task)
# Score the predictions
prediction$score(task = task)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.