Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.kkmeans: Kernel K-Means Clustering Learner

Description

A LearnerClust for kernel k-means clustering implemented in kernlab::kkmeans(). kernlab::kkmeans() doesn't have a default value for the number of clusters. Therefore, the centers parameter here is set to 2 by default. Kernel parameters have to be passed directly and not by using the kpar list in kkmeans. The predict method finds the nearest center in kernel distance to assign clusters for new data points.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.kkmeans")
lrn("clust.kkmeans")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, kernlab

Parameters

IdTypeDefaultLevelsRange
centersuntyped--
kernelcharacterrbfdotvanilladot, polydot, rbfdot, tanhdot, laplacedot, besseldot, anovadot, splinedot-
sigmanumeric-\([0, \infty)\)
degreeinteger3\([1, \infty)\)
scalenumeric1\([0, \infty)\)
offsetnumeric1\((-\infty, \infty)\)
orderinteger1\((-\infty, \infty)\)
algcharacterkkmeanskkmeans, kerninghan-
pnumeric1\((-\infty, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustKKMeans

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustKKMeans$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustKKMeans$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Karatzoglou, Alexandros, Smola, Alexandros, Hornik, Kurt, Zeileis, Achim (2004). “kernlab-an S4 package for kernel methods in R.” Journal of statistical software, 11, 1--20.

Dhillon, S I, Guan, Yuqiang, Kulis, Brian (2004). A unified view of kernel k-means, spectral clustering and graph cuts. Citeseer.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("kernlab")) {
  learner = mlr3::lrn("clust.kkmeans")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab