Learn R Programming

mlr3cluster (version 0.1.11)

mlr_learners_clust.meanshift: Mean Shift Clustering Learner

Description

A LearnerClust for Mean Shift clustering implemented in LPCM::ms(). There is no predict method for LPCM::ms(), so the method returns cluster labels for the 'training' data.

Arguments

Dictionary

This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():

mlr_learners$get("clust.meanshift")
lrn("clust.meanshift")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, LPCM

Parameters

IdTypeDefaultRange
huntyped--
subsetuntyped--
scaledinteger1\([0, \infty)\)
iterinteger200\([1, \infty)\)
thrnumeric0.01\((-\infty, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustMeanShift

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustMeanShift$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustMeanShift$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Cheng, Yizong (1995). “Mean shift, mode seeking, and clustering.” IEEE transactions on pattern analysis and machine intelligence, 17(8), 790--799.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.bico, mlr_learners_clust.birch, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.optics, mlr_learners_clust.pam, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("LPCM")) {
  learner = mlr3::lrn("clust.meanshift")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab