Learn R Programming

mlr3cluster (version 0.1.9)

mlr_learners_clust.pam: Partitioning Around Medoids Clustering Learner

Description

A LearnerClust for PAM clustering implemented in cluster::pam(). cluster::pam() doesn't have a default value for the number of clusters. Therefore, the k parameter which corresponds to the number of clusters here is set to 2 by default. The predict method uses clue::cl_predict() to compute the cluster memberships for new data.

Arguments

Dictionary

This Learner can be instantiated via the dictionary mlr_learners or with the associated sugar function lrn():

mlr_learners$get("clust.pam")
lrn("clust.pam")

Meta Information

  • Task type: “clust”

  • Predict Types: “partition”

  • Feature Types: “logical”, “integer”, “numeric”

  • Required Packages: mlr3, mlr3cluster, cluster

Parameters

IdTypeDefaultLevelsRange
kinteger-\([1, \infty)\)
metriccharacter-euclidian, manhattan-
medoidsuntyped-
standlogicalFALSETRUE, FALSE-
do.swaplogicalTRUETRUE, FALSE-
pamonceinteger0\([0, 5]\)
trace.levinteger0\([0, \infty)\)

Super classes

mlr3::Learner -> mlr3cluster::LearnerClust -> LearnerClustPAM

Methods

Inherited methods


Method new()

Creates a new instance of this R6 class.

Usage

LearnerClustPAM$new()


Method clone()

The objects of this class are cloneable with this method.

Usage

LearnerClustPAM$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

References

Reynolds, P A, Richards, Graeme, de la Iglesia, Beatriz, Rayward-Smith, J V (2006). “Clustering rules: a comparison of partitioning and hierarchical clustering algorithms.” Journal of Mathematical Modelling and Algorithms, 5, 475--504.

Schubert, Erich, Rousseeuw, J P (2019). “Faster k-medoids clustering: improving the PAM, CLARA, and CLARANS algorithms.” In Similarity Search and Applications: 12th International Conference, SISAP 2019, Newark, NJ, USA, October 2--4, 2019, Proceedings 12, 171--187. Springer.

See Also

Other Learner: mlr_learners_clust.MBatchKMeans, mlr_learners_clust.SimpleKMeans, mlr_learners_clust.agnes, mlr_learners_clust.ap, mlr_learners_clust.cmeans, mlr_learners_clust.cobweb, mlr_learners_clust.dbscan, mlr_learners_clust.dbscan_fpc, mlr_learners_clust.diana, mlr_learners_clust.em, mlr_learners_clust.fanny, mlr_learners_clust.featureless, mlr_learners_clust.ff, mlr_learners_clust.hclust, mlr_learners_clust.hdbscan, mlr_learners_clust.kkmeans, mlr_learners_clust.kmeans, mlr_learners_clust.mclust, mlr_learners_clust.meanshift, mlr_learners_clust.optics, mlr_learners_clust.xmeans

Examples

Run this code
if (requireNamespace("cluster")) {
  learner = mlr3::lrn("clust.pam")
  print(learner)

  # available parameters:
  learner$param_set$ids()
}

Run the code above in your browser using DataLab