| mlr_learners_clust.som | R Documentation |
Self-organizing map (Kohonen network) clustering.
Calls kohonen::som() from package kohonen.
Each map unit corresponds to a cluster, so the number of clusters is xdim * ydim. Grid dimensions, topology, and
neighbourhood function are exposed directly as parameters and forwarded to kohonen::somgrid(). The predict method
uses kohonen::predict.kohonen() to assign new data to the closest unit.
This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():
mlr_learners$get("clust.som")
lrn("clust.som")
Task type: “clust”
Predict Types: “partition”
Feature Types: “logical”, “integer”, “numeric”
Required Packages: mlr3, mlr3cluster, kohonen
| Id | Type | Default | Levels | Range |
| xdim | integer | 8 | [1, \infty) |
|
| ydim | integer | 6 | [1, \infty) |
|
| topo | character | rectangular | rectangular, hexagonal | - |
| neighbourhood.fct | character | bubble | bubble, gaussian | - |
| toroidal | logical | FALSE | TRUE, FALSE | - |
| rlen | integer | 100 | [1, \infty) |
|
| alpha | untyped | c(0.05, 0.01) | - | |
| radius | untyped | - | - | |
| user.weights | untyped | 1 | - | |
| maxNA.fraction | numeric | 0 | [0, 1] |
|
| keep.data | logical | TRUE | TRUE, FALSE | - |
| dist.fcts | untyped | NULL | - | |
| mode | character | online | online, batch, pbatch | - |
| cores | integer | -1 | (-\infty, \infty) |
|
| init | untyped | - | - | |
| normalizeDataLayers | logical | TRUE | TRUE, FALSE | - |
mlr3::Learner -> LearnerClust -> LearnerClustSOM
LearnerClustSOM$new()Creates a new instance of this R6 class.
LearnerClustSOM$new()
LearnerClustSOM$clone()The objects of this class are cloneable with this method.
LearnerClustSOM$clone(deep = FALSE)
deepWhether to make a deep clone.
Kohonen, Teuvo (1990). “The self-organizing map.” Proceedings of the IEEE, 78(9), 1464–1480. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1109/5.58325")}.
Wehrens, Ron, Kruisselbrink, Johannes (2018). “Flexible self-organizing maps in kohonen 3.0.” Journal of Statistical Software, 87(7), 1–18. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.18637/jss.v087.i07")}.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html#sec-learners
Package mlr3extralearners for more learners.
Dictionary of Learners: mlr3::mlr_learners
as.data.table(mlr_learners) for a table of available Learners in the running session (depending on the loaded packages).
mlr3pipelines to combine learners with pre- and postprocessing steps.
Package mlr3viz for some generic visualizations.
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
mlr3tuning for tuning of hyperparameters, mlr3tuningspaces for established default tuning spaces.
Other Learner:
mlr_learners_clust.MBatchKMeans,
mlr_learners_clust.SimpleKMeans,
mlr_learners_clust.agnes,
mlr_learners_clust.ap,
mlr_learners_clust.bico,
mlr_learners_clust.birch,
mlr_learners_clust.clara,
mlr_learners_clust.cmeans,
mlr_learners_clust.cobweb,
mlr_learners_clust.dbscan,
mlr_learners_clust.dbscan_fpc,
mlr_learners_clust.diana,
mlr_learners_clust.em,
mlr_learners_clust.fanny,
mlr_learners_clust.featureless,
mlr_learners_clust.ff,
mlr_learners_clust.flexmix,
mlr_learners_clust.genie,
mlr_learners_clust.hclust,
mlr_learners_clust.hdbscan,
mlr_learners_clust.kcca,
mlr_learners_clust.kkmeans,
mlr_learners_clust.kmeans,
mlr_learners_clust.kproto,
mlr_learners_clust.mclust,
mlr_learners_clust.meanshift,
mlr_learners_clust.movMF,
mlr_learners_clust.optics,
mlr_learners_clust.pam,
mlr_learners_clust.protoclust,
mlr_learners_clust.skmeans,
mlr_learners_clust.specc,
mlr_learners_clust.stdbscan,
mlr_learners_clust.tclust,
mlr_learners_clust.xmeans
# Define the Learner and set parameter values
learner = lrn("clust.som")
print(learner)
# Define a Task
task = tsk("usarrests")
# Train the learner on the task
learner$train(task)
# Print the model
print(learner$model)
# Make predictions for the task
prediction = learner$predict(task)
# Score the predictions
prediction$score(task = task)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.