| mlr_learners_clust.stdbscan | R Documentation |
ST-DBSCAN (spatio-temporal density-based spatial clustering of applications with noise) clustering.
Calls stdbscan::st_dbscan() from package stdbscan.
This mlr3::Learner can be instantiated via the dictionary mlr3::mlr_learners or with the associated sugar function mlr3::lrn():
mlr_learners$get("clust.stdbscan")
lrn("clust.stdbscan")
Task type: “clust”
Predict Types: “partition”
Feature Types: “integer”, “numeric”
Required Packages: mlr3, mlr3cluster, stdbscan
| Id | Type | Default | Levels | Range |
| eps_spatial | numeric | - | [0, \infty) |
|
| eps_temporal | numeric | - | [0, \infty) |
|
| min_pts | integer | - | [1, \infty) |
|
| borderPoints | logical | TRUE | TRUE, FALSE | - |
| search | character | kdtree | kdtree, linear, dist | - |
| bucketSize | integer | 10 | [1, \infty) |
|
| splitRule | character | SUGGEST | STD, MIDPT, FAIR, SL_MIDPT, SL_FAIR, SUGGEST | - |
| approx | numeric | 0 | (-\infty, \infty) |
|
mlr3::Learner -> LearnerClust -> LearnerClustSTDBSCAN
LearnerClustSTDBSCAN$new()Creates a new instance of this R6 class.
LearnerClustSTDBSCAN$new()
LearnerClustSTDBSCAN$clone()The objects of this class are cloneable with this method.
LearnerClustSTDBSCAN$clone(deep = FALSE)
deepWhether to make a deep clone.
Birant, Derya, Kut, Alp (2007). “ST-DBSCAN: An algorithm for clustering spatial-temporal data.” Data & Knowledge Engineering, 60(1), 208–221. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.datak.2006.01.013")}.
Chapter in the mlr3book: https://mlr3book.mlr-org.com/chapters/chapter2/data_and_basic_modeling.html#sec-learners
Package mlr3extralearners for more learners.
Dictionary of Learners: mlr3::mlr_learners
as.data.table(mlr_learners) for a table of available Learners in the running session (depending on the loaded packages).
mlr3pipelines to combine learners with pre- and postprocessing steps.
Package mlr3viz for some generic visualizations.
Extension packages for additional task types:
mlr3proba for probabilistic supervised regression and survival analysis.
mlr3cluster for unsupervised clustering.
mlr3tuning for tuning of hyperparameters, mlr3tuningspaces for established default tuning spaces.
Other Learner:
mlr_learners_clust.MBatchKMeans,
mlr_learners_clust.SimpleKMeans,
mlr_learners_clust.agnes,
mlr_learners_clust.ap,
mlr_learners_clust.bico,
mlr_learners_clust.birch,
mlr_learners_clust.clara,
mlr_learners_clust.cmeans,
mlr_learners_clust.cobweb,
mlr_learners_clust.dbscan,
mlr_learners_clust.dbscan_fpc,
mlr_learners_clust.diana,
mlr_learners_clust.em,
mlr_learners_clust.fanny,
mlr_learners_clust.featureless,
mlr_learners_clust.ff,
mlr_learners_clust.flexmix,
mlr_learners_clust.genie,
mlr_learners_clust.hclust,
mlr_learners_clust.hdbscan,
mlr_learners_clust.kcca,
mlr_learners_clust.kkmeans,
mlr_learners_clust.kmeans,
mlr_learners_clust.kproto,
mlr_learners_clust.mclust,
mlr_learners_clust.meanshift,
mlr_learners_clust.movMF,
mlr_learners_clust.optics,
mlr_learners_clust.pam,
mlr_learners_clust.protoclust,
mlr_learners_clust.skmeans,
mlr_learners_clust.som,
mlr_learners_clust.specc,
mlr_learners_clust.tclust,
mlr_learners_clust.xmeans
# Define the Learner and set parameter values
learner = lrn("clust.stdbscan")
print(learner)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.