| mlr_measures_clust.wb_ratio | R Documentation |
The ratio of the average within-cluster distance to the average between-cluster distance. The average within-cluster distance is the weighted mean of all pairwise distances within each cluster, and the average between-cluster distance is the mean of all pairwise distances between observations in different clusters. Lower values indicate compact clusters that are well separated from each other.
If the task contains factor or ordered features, Gower distances (cluster::daisy()) are used instead of
Euclidean distances.
This mlr3::Measure can be instantiated via the dictionary mlr3::mlr_measures or with the
associated sugar function mlr3::msr():
mlr_measures$get("clust.wb_ratio")
msr("clust.wb_ratio")
Task type: “clust”
Range: [0, \infty)
Minimize: TRUE
Average: macro
Required Prediction: “partition”
Required Packages: mlr3, mlr3cluster, cluster
Dictionary of Measures: mlr3::mlr_measures
as.data.table(mlr_measures) for a complete table of all (also dynamically created) mlr3::Measure implementations.
Other cluster measures:
mlr_measures_clust.avg_between,
mlr_measures_clust.avg_within,
mlr_measures_clust.ch,
mlr_measures_clust.davies_bouldin,
mlr_measures_clust.dunn,
mlr_measures_clust.dunn2,
mlr_measures_clust.entropy,
mlr_measures_clust.pearsongamma,
mlr_measures_clust.silhouette,
mlr_measures_clust.wss
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.